ActionChipDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

ActionChipDj({dynamic key, dynamic avatar, dynamic label, dynamic labelStyle, dynamic labelPadding, dynamic onPressed, dynamic pressElevation, dynamic tooltip, dynamic side, dynamic shape, dynamic clipBehavior, dynamic focusNode, dynamic autofocus, dynamic backgroundColor, dynamic padding, dynamic visualDensity, dynamic materialTapTargetSize, dynamic elevation, dynamic shadowColor, dynamic baseWidgetDjType = 'ActionChip'})
ActionChipDj.fromJson(Map<String, dynamic> json)
factory

Properties

autofocus → dynamic
final
avatar → dynamic
final
backgroundColor → dynamic
final
baseWidgetDjType String
finalinherited
clipBehavior → dynamic
final
codePartDjType CodePartDjType?
finalinherited
descriptionDj String?
finalinherited
elevation → dynamic
final
focusNode → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
key ↔ dynamic
getter/setter pair
label → dynamic
final
labelPadding → dynamic
final
labelStyle → dynamic
final
materialTapTargetSize → dynamic
final
onPressed → dynamic
final
padding → dynamic
final
pressElevation → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → dynamic
final
shape → dynamic
final
side → dynamic
final
tooltip → dynamic
final
visualDensity → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited