AnimatedModalBarrierDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

AnimatedModalBarrierDj({dynamic key, dynamic color, dynamic dismissible, dynamic semanticsLabel, dynamic barrierSemanticsDismissible, dynamic baseWidgetDjType = 'AnimatedModalBarrier'})
AnimatedModalBarrierDj.fromJson(Map<String, dynamic> json)
factory

Properties

barrierSemanticsDismissible → dynamic
final
baseWidgetDjType String
finalinherited
codePartDjType CodePartDjType?
finalinherited
color ↔ dynamic
getter/setter pair
descriptionDj String?
finalinherited
dismissible → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
key ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited