AssetImageDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

AssetImageDj({dynamic assetName, dynamic bundle, dynamic package, dynamic baseWidgetDjType = 'AssetImage'})
AssetImageDj.fromJson(Map<String, dynamic> json)
factory

Properties

assetName → dynamic
final
baseWidgetDjType String
finalinherited
bundle → dynamic
final
codePartDjType CodePartDjType?
finalinherited
descriptionDj String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
package → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited