splashColor property
- @JsonKey.new(name: 'splashColor')
getter/setter pair
Implementation
@JsonKey(name: 'splashColor')
// Setting data type of this field to be 'dynamic' instead of
// 'Color?' for now.
dynamic splashColor;
@JsonKey(name: 'splashColor')
// Setting data type of this field to be 'dynamic' instead of
// 'Color?' for now.
dynamic splashColor;