CheckboxListTileDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

CheckboxListTileDj({dynamic key, dynamic value, dynamic onChanged, dynamic activeColor, dynamic checkColor, dynamic tileColor, dynamic title, dynamic subtitle, dynamic isThreeLine, dynamic dense, dynamic secondary, dynamic selected, dynamic controlAffinity, dynamic autofocus, dynamic contentPadding, dynamic tristate, dynamic shape, dynamic selectedTileColor, dynamic baseWidgetDjType = 'CheckboxListTile'})
CheckboxListTileDj.fromJson(Map<String, dynamic> json)
factory

Properties

activeColor → dynamic
final
autofocus → dynamic
final
baseWidgetDjType String
finalinherited
checkColor → dynamic
final
codePartDjType CodePartDjType?
finalinherited
contentPadding → dynamic
final
controlAffinity → dynamic
final
dense → dynamic
final
descriptionDj String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isThreeLine → dynamic
final
key ↔ dynamic
getter/setter pair
onChanged → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary → dynamic
final
selected → dynamic
final
selectedTileColor → dynamic
final
shape → dynamic
final
subtitle → dynamic
final
tileColor → dynamic
final
title → dynamic
final
tristate → dynamic
final
value → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited