ChipThemeDataDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

ChipThemeDataDj({dynamic backgroundColor, dynamic deleteIconColor, dynamic disabledColor, dynamic selectedColor, dynamic secondarySelectedColor, dynamic shadowColor, dynamic selectedShadowColor, dynamic showCheckmark, dynamic checkmarkColor, dynamic labelPadding, dynamic padding, dynamic side, dynamic shape, dynamic labelStyle, dynamic secondaryLabelStyle, dynamic brightness, dynamic elevation, dynamic pressElevation, dynamic baseWidgetDjType = 'ChipThemeData'})
ChipThemeDataDj.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundColor → dynamic
final
baseWidgetDjType String
finalinherited
brightness → dynamic
final
checkmarkColor → dynamic
final
codePartDjType CodePartDjType?
finalinherited
deleteIconColor → dynamic
final
descriptionDj String?
finalinherited
disabledColor → dynamic
final
elevation → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
labelPadding → dynamic
final
labelStyle → dynamic
final
padding → dynamic
final
pressElevation → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryLabelStyle → dynamic
final
secondarySelectedColor → dynamic
final
selectedColor → dynamic
final
selectedShadowColor → dynamic
final
shadowColor → dynamic
final
shape → dynamic
final
showCheckmark → dynamic
final
side → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited