ColorSchemeDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

ColorSchemeDj({dynamic primary, dynamic primaryVariant, dynamic secondary, dynamic secondaryVariant, dynamic surface, dynamic background, dynamic error, dynamic onPrimary, dynamic onSecondary, dynamic onSurface, dynamic onBackground, dynamic onError, dynamic brightness, dynamic baseWidgetDjType = 'ColorScheme'})
ColorSchemeDj.fromJson(Map<String, dynamic> json)
factory

Properties

background → dynamic
final
baseWidgetDjType String
finalinherited
brightness → dynamic
final
codePartDjType CodePartDjType?
finalinherited
descriptionDj String?
finalinherited
error → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
onBackground → dynamic
final
onError → dynamic
final
onPrimary → dynamic
final
onSecondary → dynamic
final
onSurface → dynamic
final
primary → dynamic
final
primaryVariant → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary → dynamic
final
secondaryVariant → dynamic
final
surface → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited