DataTableThemeDataDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

DataTableThemeDataDj({dynamic decoration, dynamic dataRowColor, dynamic dataRowHeight, dynamic dataTextStyle, dynamic headingRowColor, dynamic headingRowHeight, dynamic headingTextStyle, dynamic horizontalMargin, dynamic columnSpacing, dynamic dividerThickness, dynamic checkboxHorizontalMargin, dynamic baseWidgetDjType = 'DataTableThemeData'})
DataTableThemeDataDj.fromJson(Map<String, dynamic> json)
factory

Properties

baseWidgetDjType String
finalinherited
checkboxHorizontalMargin → dynamic
final
codePartDjType CodePartDjType?
finalinherited
columnSpacing → dynamic
final
dataRowColor → dynamic
final
dataRowHeight → dynamic
final
dataTextStyle → dynamic
final
decoration → dynamic
final
descriptionDj String?
finalinherited
dividerThickness → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
headingRowColor → dynamic
final
headingRowHeight → dynamic
final
headingTextStyle → dynamic
final
horizontalMargin → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited