DateTimeRangeDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

DateTimeRangeDj({dynamic start, dynamic end, dynamic baseWidgetDjType = 'DateTimeRange'})
DateTimeRangeDj.fromJson(Map<String, dynamic> json)
factory

Properties

baseWidgetDjType String
finalinherited
codePartDjType CodePartDjType?
finalinherited
descriptionDj String?
finalinherited
end → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited