stackFilter property
- @JsonKey.new(name: 'stackFilter')
getter/setter pair
Implementation
@JsonKey(name: 'stackFilter')
// Setting data type of this field to be 'dynamic' instead of
// 'IterableFilter<String>?' for now.
dynamic stackFilter;
@JsonKey(name: 'stackFilter')
// Setting data type of this field to be 'dynamic' instead of
// 'IterableFilter<String>?' for now.
dynamic stackFilter;