DragTargetDj class
- Inheritance
-
- Object
- CodePartDj
- BaseWidgetDj
- DragTargetDj
- Annotations
-
- @JsonSerializable.new()
Constructors
- DragTargetDj({dynamic key, dynamic builder, dynamic onWillAccept, dynamic onAccept, dynamic onAcceptWithDetails, dynamic onLeave, dynamic onMove, dynamic hitTestBehavior, dynamic baseWidgetDjType = 'DragTarget'})
-
DragTargetDj.fromJson(Map<
String, dynamic> json) -
factory
Properties
- baseWidgetDjType → String
-
finalinherited
- builder → dynamic
-
final
- codePartDjType → CodePartDjType?
-
finalinherited
- descriptionDj → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hitTestBehavior → dynamic
-
final
- key ↔ dynamic
-
getter/setter pair
- onAccept → dynamic
-
final
- onAcceptWithDetails → dynamic
-
final
- onLeave → dynamic
-
final
- onMove → dynamic
-
final
- onWillAccept → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCode(
) → List< String> -
override
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited