FlutterErrorDetailsForPointerEventDispatcherDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

FlutterErrorDetailsForPointerEventDispatcherDj({dynamic exception, dynamic stack, dynamic library, dynamic context, dynamic event, dynamic hitTestEntry, dynamic informationCollector, dynamic silent, dynamic baseWidgetDjType = 'FlutterErrorDetailsForPointerEventDispatcher'})
FlutterErrorDetailsForPointerEventDispatcherDj.fromJson(Map<String, dynamic> json)
factory

Properties

baseWidgetDjType String
finalinherited
codePartDjType CodePartDjType?
finalinherited
context ↔ dynamic
getter/setter pair
descriptionDj String?
finalinherited
event → dynamic
final
exception ↔ dynamic
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hitTestEntry → dynamic
final
informationCollector ↔ dynamic
getter/setter pair
library ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
silent ↔ dynamic
getter/setter pair
stack ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited