stack property
- @JsonKey.new(name: 'stack')
getter/setter pair
Implementation
@JsonKey(name: 'stack')
// Setting data type of this field to be 'dynamic' instead of
// 'StackTrace?' for now.
dynamic stack;
@JsonKey(name: 'stack')
// Setting data type of this field to be 'dynamic' instead of
// 'StackTrace?' for now.
dynamic stack;