FocusScopeDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

FocusScopeDj({dynamic key, dynamic node, dynamic child, dynamic autofocus, dynamic onFocusChange, dynamic canRequestFocus, dynamic skipTraversal, dynamic onKey, dynamic debugLabel, dynamic baseWidgetDjType = 'FocusScope'})
FocusScopeDj.fromJson(Map<String, dynamic> json)
factory

Properties

autofocus ↔ dynamic
getter/setter pair
baseWidgetDjType String
finalinherited
canRequestFocus ↔ dynamic
getter/setter pair
child ↔ dynamic
getter/setter pair
codePartDjType CodePartDjType?
finalinherited
debugLabel ↔ dynamic
getter/setter pair
descriptionDj String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key ↔ dynamic
getter/setter pair
node ↔ dynamic
getter/setter pair
onFocusChange ↔ dynamic
getter/setter pair
onKey ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipTraversal ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited