MessagePropertyDj class
- Inheritance
-
- Object
- CodePartDj
- BaseWidgetDj
- MessagePropertyDj
- Annotations
-
- @JsonSerializable.new()
Constructors
- MessagePropertyDj({dynamic name, dynamic message, dynamic style, dynamic level, dynamic baseWidgetDjType = 'MessageProperty'})
-
MessagePropertyDj.fromJson(Map<
String, dynamic> json) -
factory
Properties
- baseWidgetDjType → String
-
finalinherited
- codePartDjType → CodePartDjType?
-
finalinherited
- descriptionDj → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- level ↔ dynamic
-
getter/setter pair
- message ↔ dynamic
-
getter/setter pair
- name ↔ dynamic
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style ↔ dynamic
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCode(
) → List< String> -
override
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited