PhysicalModelDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

PhysicalModelDj({dynamic key, dynamic shape, dynamic clipBehavior, dynamic borderRadius, dynamic elevation, dynamic color, dynamic baseWidgetDjType = 'PhysicalModel'})
PhysicalModelDj.fromJson(Map<String, dynamic> json)
factory

Properties

baseWidgetDjType String
finalinherited
borderRadius → dynamic
final
clipBehavior → dynamic
final
codePartDjType CodePartDjType?
finalinherited
color → dynamic
final
descriptionDj String?
finalinherited
elevation → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
key ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited