distanceMax property
- @JsonKey.new(name: 'distanceMax')
getter/setter pair
Implementation
@JsonKey(name: 'distanceMax')
// Setting data type of this field to be 'dynamic' instead of
// 'double' for now.
dynamic distanceMax;
@JsonKey(name: 'distanceMax')
// Setting data type of this field to be 'dynamic' instead of
// 'double' for now.
dynamic distanceMax;