pressureMax property
- @JsonKey.new(name: 'pressureMax')
getter/setter pair
Implementation
@JsonKey(name: 'pressureMax')
// Setting data type of this field to be 'dynamic' instead of
// 'double' for now.
dynamic pressureMax;
@JsonKey(name: 'pressureMax')
// Setting data type of this field to be 'dynamic' instead of
// 'double' for now.
dynamic pressureMax;