RawAutocompleteDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

RawAutocompleteDj({dynamic key, dynamic optionsViewBuilder, dynamic optionsBuilder, dynamic displayStringForOption, dynamic fieldViewBuilder, dynamic focusNode, dynamic onSelected, dynamic textEditingController, dynamic baseWidgetDjType = 'RawAutocomplete'})
RawAutocompleteDj.fromJson(Map<String, dynamic> json)
factory

Properties

baseWidgetDjType String
finalinherited
codePartDjType CodePartDjType?
finalinherited
descriptionDj String?
finalinherited
displayStringForOption → dynamic
final
fieldViewBuilder → dynamic
final
focusNode → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
key ↔ dynamic
getter/setter pair
onSelected → dynamic
final
optionsBuilder → dynamic
final
optionsViewBuilder → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textEditingController → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited