RawMaterialButtonDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

RawMaterialButtonDj({dynamic key, dynamic onPressed, dynamic onLongPress, dynamic onHighlightChanged, dynamic mouseCursor, dynamic textStyle, dynamic fillColor, dynamic focusColor, dynamic hoverColor, dynamic highlightColor, dynamic splashColor, dynamic elevation, dynamic focusElevation, dynamic hoverElevation, dynamic highlightElevation, dynamic disabledElevation, dynamic padding, dynamic visualDensity, dynamic baseWidgetDjType = 'RawMaterialButton'})
RawMaterialButtonDj.fromJson(Map<String, dynamic> json)
factory

Properties

baseWidgetDjType String
finalinherited
codePartDjType CodePartDjType?
finalinherited
descriptionDj String?
finalinherited
disabledElevation → dynamic
final
elevation → dynamic
final
fillColor → dynamic
final
focusColor → dynamic
final
focusElevation → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
highlightColor → dynamic
final
highlightElevation → dynamic
final
hoverColor → dynamic
final
hoverElevation → dynamic
final
key ↔ dynamic
getter/setter pair
mouseCursor → dynamic
final
onHighlightChanged → dynamic
final
onLongPress → dynamic
final
onPressed → dynamic
final
padding → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splashColor → dynamic
final
textStyle → dynamic
final
visualDensity → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited