RenderAnimatedSizeDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

RenderAnimatedSizeDj({dynamic vsync, dynamic duration, dynamic reverseDuration, dynamic curve, dynamic alignment, dynamic textDirection, dynamic child, dynamic clipBehavior, dynamic baseWidgetDjType = 'RenderAnimatedSize'})
RenderAnimatedSizeDj.fromJson(Map<String, dynamic> json)
factory

Properties

alignment ↔ dynamic
getter/setter pair
baseWidgetDjType String
finalinherited
child ↔ dynamic
getter/setter pair
clipBehavior ↔ dynamic
getter/setter pair
codePartDjType CodePartDjType?
finalinherited
curve ↔ dynamic
getter/setter pair
descriptionDj String?
finalinherited
duration ↔ dynamic
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
reverseDuration ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textDirection ↔ dynamic
getter/setter pair
vsync ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited