ScrollDragControllerDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

ScrollDragControllerDj({dynamic delegate, dynamic details, dynamic onDragCanceled, dynamic carriedVelocity, dynamic motionStartDistanceThreshold, dynamic baseWidgetDjType = 'ScrollDragController'})
ScrollDragControllerDj.fromJson(Map<String, dynamic> json)
factory

Properties

baseWidgetDjType String
finalinherited
carriedVelocity → dynamic
final
codePartDjType CodePartDjType?
finalinherited
delegate ↔ dynamic
getter/setter pair
descriptionDj String?
finalinherited
details ↔ dynamic
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
motionStartDistanceThreshold → dynamic
final
onDragCanceled → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited