ScrollableDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

ScrollableDj({dynamic key, dynamic axisDirection, dynamic controller, dynamic physics, dynamic viewportBuilder, dynamic incrementCalculator, dynamic excludeFromSemantics, dynamic semanticChildCount, dynamic dragStartBehavior, dynamic restorationId, dynamic scrollBehavior, dynamic baseWidgetDjType = 'Scrollable'})
ScrollableDj.fromJson(Map<String, dynamic> json)
factory

Properties

axisDirection → dynamic
final
baseWidgetDjType String
finalinherited
codePartDjType CodePartDjType?
finalinherited
controller → dynamic
final
descriptionDj String?
finalinherited
dragStartBehavior → dynamic
final
excludeFromSemantics → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
incrementCalculator → dynamic
final
key ↔ dynamic
getter/setter pair
physics → dynamic
final
restorationId → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollBehavior → dynamic
final
semanticChildCount → dynamic
final
viewportBuilder → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited