SizeTransitionDj class
- Inheritance
-
- Object
- CodePartDj
- BaseWidgetDj
- SizeTransitionDj
- Annotations
-
- @JsonSerializable.new()
Constructors
- SizeTransitionDj({dynamic key, dynamic axis, dynamic sizeFactor, dynamic axisAlignment, dynamic child, dynamic baseWidgetDjType = 'SizeTransition'})
-
SizeTransitionDj.fromJson(Map<
String, dynamic> json) -
factory
Properties
- axis → dynamic
-
final
- axisAlignment → dynamic
-
final
- baseWidgetDjType → String
-
finalinherited
- child → dynamic
-
final
- codePartDjType → CodePartDjType?
-
finalinherited
- descriptionDj → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- key ↔ dynamic
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeFactor ↔ dynamic
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCode(
) → List< String> -
override
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited