SizedBoxDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

SizedBoxDj({dynamic key, dynamic width, dynamic height, dynamic child, dynamic baseWidgetDjType = 'SizedBox'})
SizedBoxDj.fromJson(Map<String, dynamic> json)
factory

Properties

baseWidgetDjType String
finalinherited
child ↔ dynamic
getter/setter pair
codePartDjType CodePartDjType?
finalinherited
descriptionDj String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
height → dynamic
final
key ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited