spring property
- @JsonKey.new(name: 'spring')
getter/setter pair
Implementation
@JsonKey(name: 'spring')
// Setting data type of this field to be 'dynamic' instead of
// 'SpringDescription' for now.
dynamic spring;
@JsonKey(name: 'spring')
// Setting data type of this field to be 'dynamic' instead of
// 'SpringDescription' for now.
dynamic spring;