TextInputConfigurationDj class
- Inheritance
-
- Object
- CodePartDj
- BaseWidgetDj
- TextInputConfigurationDj
- Annotations
-
- @JsonSerializable.new()
Constructors
- TextInputConfigurationDj({dynamic inputType, dynamic readOnly, dynamic obscureText, dynamic autocorrect, dynamic smartDashesType, dynamic smartQuotesType, dynamic enableSuggestions, dynamic actionLabel, dynamic inputAction, dynamic keyboardAppearance, dynamic textCapitalization, dynamic autofillConfiguration, dynamic baseWidgetDjType = 'TextInputConfiguration'})
-
TextInputConfigurationDj.fromJson(Map<
String, dynamic> json) -
factory
Properties
- actionLabel → dynamic
-
final
- autocorrect → dynamic
-
final
- autofillConfiguration → dynamic
-
final
- baseWidgetDjType → String
-
finalinherited
- codePartDjType → CodePartDjType?
-
finalinherited
- descriptionDj → String?
-
finalinherited
- enableSuggestions → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputAction → dynamic
-
final
- inputType → dynamic
-
final
- keyboardAppearance → dynamic
-
final
- obscureText → dynamic
-
final
- readOnly → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- smartDashesType ↔ dynamic
-
getter/setter pair
- smartQuotesType ↔ dynamic
-
getter/setter pair
- textCapitalization → dynamic
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCode(
) → List< String> -
override
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited