TextSpanDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

TextSpanDj({dynamic text, dynamic children, dynamic style, dynamic recognizer, dynamic mouseCursor, dynamic onEnter, dynamic onExit, dynamic semanticsLabel, dynamic baseWidgetDjType = 'TextSpan'})
TextSpanDj.fromJson(Map<String, dynamic> json)
factory

Properties

baseWidgetDjType String
finalinherited
children → dynamic
final
codePartDjType CodePartDjType?
finalinherited
descriptionDj String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
mouseCursor ↔ dynamic
getter/setter pair
onEnter → dynamic
final
onExit → dynamic
final
recognizer → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → dynamic
final
style ↔ dynamic
getter/setter pair
text → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited