TextTreeConfigurationDj class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

TextTreeConfigurationDj({dynamic prefixLineOne, dynamic prefixOtherLines, dynamic prefixLastChildLineOne, dynamic prefixOtherLinesRootNode, dynamic linkCharacter, dynamic propertyPrefixIfChildren, dynamic propertyPrefixNoChildren, dynamic lineBreak, dynamic lineBreakProperties, dynamic afterName, dynamic afterDescriptionIfBody, dynamic afterDescription, dynamic beforeProperties, dynamic afterProperties, dynamic mandatoryAfterProperties, dynamic propertySeparator, dynamic bodyIndent, dynamic footer, dynamic showChildren, dynamic addBlankLineIfNoChildren, dynamic isNameOnOwnLine, dynamic isBlankLineBetweenPropertiesAndChildren, dynamic beforeName, dynamic suffixLineOne, dynamic mandatoryFooter, dynamic baseWidgetDjType = 'TextTreeConfiguration'})
TextTreeConfigurationDj.fromJson(Map<String, dynamic> json)
factory

Properties

addBlankLineIfNoChildren → dynamic
final
afterDescription → dynamic
final
afterDescriptionIfBody → dynamic
final
afterName → dynamic
final
afterProperties → dynamic
final
baseWidgetDjType String
finalinherited
beforeName → dynamic
final
beforeProperties → dynamic
final
bodyIndent → dynamic
final
codePartDjType CodePartDjType?
finalinherited
descriptionDj String?
finalinherited
final
hashCode int
The hash code for this object.
no setterinherited
isBlankLineBetweenPropertiesAndChildren → dynamic
final
isNameOnOwnLine → dynamic
final
lineBreak → dynamic
final
lineBreakProperties → dynamic
final
linkCharacter → dynamic
final
mandatoryAfterProperties → dynamic
final
mandatoryFooter → dynamic
final
prefixLastChildLineOne → dynamic
final
prefixLineOne → dynamic
final
prefixOtherLines → dynamic
final
prefixOtherLinesRootNode → dynamic
final
propertyPrefixIfChildren → dynamic
final
propertyPrefixNoChildren → dynamic
final
propertySeparator → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showChildren → dynamic
final
suffixLineOne → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCode() List<String>
override
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited