BottomNavigationBarDj class
- Inheritance
-
- Object
- CodePartDj
- BaseWidgetDj
- BottomNavigationBarDj
- Annotations
-
- @JsonSerializable.new()
Constructors
-
factory
Properties
- backgroundColor → dynamic
-
final
- baseWidgetDjType → String
-
finalinherited
- codePartDjType → CodePartDjType?
-
finalinherited
- currentIndex → dynamic
-
final
- descriptionDj → String?
-
finalinherited
- elevation → dynamic
-
final
- enableFeedback → dynamic
-
final
- fixedColor ↔ dynamic
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconSize → dynamic
-
final
- items → dynamic
-
final
- key ↔ dynamic
-
getter/setter pair
- mouseCursor → dynamic
-
final
- onTap → dynamic
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedFontSize → dynamic
-
final
- selectedIconTheme → dynamic
-
final
- selectedItemColor ↔ dynamic
-
getter/setter pair
- selectedLabelStyle → dynamic
-
final
- showSelectedLabels → dynamic
-
final
- showUnselectedLabels → dynamic
-
final
- type → dynamic
-
final
- unselectedFontSize → dynamic
-
final
- unselectedIconTheme → dynamic
-
final
- unselectedItemColor → dynamic
-
final
- unselectedLabelStyle → dynamic
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCode(
) → List< String> -
override
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited