TextSelectionThemeDataDj class
- Inheritance
-
- Object
- CodePartDj
- BaseWidgetDj
- TextSelectionThemeDataDj
- Annotations
-
- @JsonSerializable.new()
Constructors
- TextSelectionThemeDataDj({dynamic cursorColor, dynamic selectionColor, dynamic selectionHandleColor, dynamic baseWidgetDjType = 'TextSelectionThemeData'})
-
TextSelectionThemeDataDj.fromJson(Map<
String, dynamic> json) -
factory
Properties
- baseWidgetDjType → String
-
finalinherited
- codePartDjType → CodePartDjType?
-
finalinherited
- cursorColor → dynamic
-
final
- descriptionDj → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionColor → dynamic
-
final
- selectionHandleColor → dynamic
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCode(
) → List< String> -
override
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited